@@ -1,13 +1,13 @@
 
 # The R Commander and command logger
 
-# last modified 19 December 2008 by J. Fox
+# last modified 24 February 2009 by J. Fox
 #   slight changes 12 Aug 04 by Ph. Grosjean
 #   changes 21 June 2007 by Erich Neuwirth for Excel support (marked EN)
 # last modified 17 December 2008 by Richard Heiberger  ##rmh
 
 Commander <- function(){
-	RcmdrVersion <- "1.4-7"
+	RcmdrVersion <- "1.4-8"
 	##    DESCRIPTION <- readLines(file.path(.find.package("Rcmdr"), "DESCRIPTION")[1])
 	##    RcmdrVersion <- trim.blanks(sub("^Version:", "",
 	##        grep("^Version:", D, value=TRUE)))
@@ -171,7 +171,8 @@ Commander <- function(){
 	setOption("warning.text.color", "darkgreen")
 	setOption("multiple.select.mode", "extended")
 	setOption("suppress.X11.warnings",
-		interactive() && .Platform$GUI == "X11" && getRversion() < "2.4.0") # to address problem in Linux
+		interactive() && .Platform$GUI == "X11") # to address problem in X11 (Linux or Mac OS X)
+#		interactive() && .Platform$GUI == "X11" && getRversion() < "2.4.0")
 	setOption("showData.threshold", 100)
 	setOption("retain.messages", TRUE)
 	setOption("crisp.dialogs",  TRUE)
@@ -429,12 +430,12 @@ Commander <- function(){
 				if (Menus[m, 3] == "command"){
 					position[Menus[m, 2]] <- position[Menus[m, 2]] + 1
 					if (Menus[m, 6] == "")
-						tkadd(get(Menus[m, 2]), "command", label=gettextRcmdr(Menus[m, 4]),
+						tkadd(get(Menus[m, 2]), "command", label=gettextMenus(Menus[m, 4]),
 							command=get(Menus[m, 5]))
 #                        tkadd(eval(parse(text=Menus[m, 2])),"command", label=gettextRcmdr(Menus[m, 4]),
 #                            command=eval(parse(text=Menus[m, 5])))
 					else {
-						tkadd(get(Menus[m, 2]), "command", label=gettextRcmdr(Menus[m, 4]),
+						tkadd(get(Menus[m, 2]), "command", label=gettextMenus(Menus[m, 4]),
 							command=get(Menus[m, 5]), state="disabled")
 #                        tkadd(eval(parse(text=Menus[m, 2])),"command", label=gettextRcmdr(Menus[m, 4]),
 #                            command=eval(parse(text=Menus[m, 5])),  state="disabled")
@@ -445,7 +446,7 @@ Commander <- function(){
 					}
 				}
 				else if (Menus[m, 3] == "cascade")
-					tkadd(get(Menus[m, 2]), "cascade", label=gettextRcmdr(Menus[m, 4]),
+					tkadd(get(Menus[m, 2]), "cascade", label=gettextMenus(Menus[m, 4]),
 						menu=get(Menus[m, 5]))
 #                    tkadd(eval(parse(text=Menus[m, 2])),"cascade", label=gettextRcmdr(Menus[m, 4]),
 #                        menu=eval(parse(text=Menus[m, 5])))
